@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-compat
-version: 0.3.2.0
-id: aeson-compat-0.3.2.0-1377f830a9c306c394b4385c9d316f98
-key: aeson_DmMoGnpe6aY79UtFqvnefC
+version: 0.3.3.0
+id: aeson-compat-0.3.3.0-52f5c04d7d0fac842ea3a64bb05beba5
+key: aeson_CqVb5SUFFkE7KseLcWMvhY
 license: BSD3
 maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
 homepage: https://github.com/phadej/aeson-compat#readme
@@ -17,13 +17,13 @@ exposed-modules:
     Data.Aeson.Compat
 hidden-modules: Data.Aeson.Compat.Time
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.2.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.2.0
-hs-libraries: HSaeson-compat-0.3.2.0-DmMoGnpe6aY79UtFqvnefC
+import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.3.0
+library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-compat-0.3.3.0
+data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-compat-0.3.3.0
+hs-libraries: HSaeson-compat-0.3.3.0-CqVb5SUFFkE7KseLcWMvhY
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
-    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     base-compat-0.9.1-b27a2a11ed624cad5ac469eab39183ee
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
@@ -31,8 +31,8 @@ depends:
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
     hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
     scientific-0.3.4.6-7ee193f22b0f4a7e2e484deeaee5cd03
-    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    semigroups-0.18.1-1d5ad88275231b75d5bd2afbb0ecbbe4
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     time-locale-compat-0.1.1.1-4bbdeebce90c671369911a4d16cfee44
